2 ms·
So, we have basically rewritten the tornado patch idea using the C++17 string_view API (subset implemented in APT::StringView). This improved performance by abo
by julian-klode 11y ago
So, we have basically rewritten the tornado patch idea using the C++17 string_view API (subset implemented in APT::StringView). This improved performance by about 10% on my test systems.
Here's the commit:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=eff0c22e59e65b6b63e854ff41eb091278e05714 http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=eff0c2...
also further improvement:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=dd592790c8f1be4925f74266742c163516ab80c7 http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=dd5927...
and finally, dropping strings out of StoreString(), so it's now almost entirely gone:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=869700d839a1695fe00734592bd504d59386e4b9 http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=869700...